@@ -29,13 +29,12 @@
 
 (eval-when-compile
   (require 'cl-lib))
-(require 'cursor-sensor)
+(require 'ring)
 (require 'flymake)
 (require 'markdown-overlays)
-(require 'ring)
 (require 'shell-maker)
-(require 'svg nil :noerror)
 (require 'transient)
+(require 'svg nil :noerror)
 
 (declare-function chatgpt-shell--eshell-last-last-command "chatgpt-shell")
 (declare-function chatgpt-shell--fetch-model-icon "chatgpt-shell")
@@ -119,8 +118,7 @@ t if invoked from a transient frame (quitting closes the frame).")
 
 (define-derived-mode chatgpt-shell-prompt-compose-mode fundamental-mode "LLM Prompt Compose"
   "Major mode for composing chatgpt-shell LLM prompts from a dedicated buffer."
-  :keymap chatgpt-shell-prompt-compose-mode-map
-  (cursor-intangible-mode +1))
+  :keymap chatgpt-shell-prompt-compose-mode-map)
 
 (defvar chatgpt-shell-prompt-compose-view-mode-map
   (let ((map (make-sparse-keymap)))
@@ -377,7 +375,6 @@ Optionally set its PROMPT and RESPONSE."
   (let ((inhibit-read-only t))
     (erase-buffer)
     (insert (chatgpt-shell-prompt-compose--history-label))
-    (goto-char (point-max))
     (when prompt
       (insert
        (if chatgpt-shell-prompt-compose-view-mode
@@ -574,19 +571,15 @@ If BACKWARDS is non-nil, go to previous interaction."
                                        (buffer-string)))
                     'ignore t
                     'read-only t
-                    'cursor-intangible t
                     'face font-lock-comment-face
-                    'rear-nonsticky '(cursor-intangible read-only ignore)
-                    'front-sticky '(cursor-intangible read-only ignore)))
+                    'rear-nonsticky t))
     (let ((pos (or (chatgpt-shell-prompt-compose--position)
                    (cons 1 1))))
       (propertize (format "[%d/%d]\n\n" (car pos) (cdr pos))
                   'ignore t
                   'read-only t
-                  'cursor-intangible t
                   'face font-lock-comment-face
-                  'rear-nonsticky '(cursor-intangible read-only ignore)
-                  'front-sticky '(cursor-intangible read-only ignore)))))
+                  'rear-nonsticky t))))
 
 (defun chatgpt-shell-prompt-compose--position ()
   "Return the position in history of the primary shell buffer."
